@@ -35,12 +35,11 @@ class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceIdTarget",
 ):
-    """An EC2 instance that is the target for load balancing.
+    """(experimental) An EC2 instance that is the target for load balancing.
 
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can connect to the instance.
 
-    stability
     :stability: experimental
     """
 
@@ -49,12 +48,11 @@ class InstanceIdTarget(
         instance_id: builtins.str,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """Create a new Instance target.
+        """(experimental) Create a new Instance target.
 
         :param instance_id: Instance ID of the instance to register to.
         :param port: Override the default port for the target group.
 
-        stability
         :stability: experimental
         """
         jsii.create(InstanceIdTarget, self, [instance_id, port])
@@ -64,14 +62,13 @@ class InstanceIdTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
@@ -81,14 +78,13 @@ class InstanceIdTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
@@ -100,7 +96,6 @@ class InstanceTarget(
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceTarget",
 ):
     """
-    stability
     :stability: experimental
     """
 
@@ -109,12 +104,11 @@ class InstanceTarget(
         instance: aws_cdk.aws_ec2.Instance,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """Create a new Instance target.
+        """(experimental) Create a new Instance target.
 
         :param instance: Instance to register to.
         :param port: Override the default port for the target group.
 
-        stability
         :stability: experimental
         """
         jsii.create(InstanceTarget, self, [instance, port])
@@ -125,7 +119,7 @@ class IpTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.IpTarget",
 ):
-    """An IP address that is a target for load balancing.
+    """(experimental) An IP address that is a target for load balancing.
 
     Specify IP addresses from the subnets of the virtual private cloud (VPC) for
     the target group, the RFC 1918 range (10.0.0.0/8, 172.16.0.0/12, and
@@ -135,7 +129,6 @@ class IpTarget(
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can send packets to the IP address.
 
-    stability
     :stability: experimental
     """
 
@@ -145,7 +138,7 @@ class IpTarget(
         port: typing.Optional[jsii.Number] = None,
         availability_zone: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Create a new IPAddress target.
+        """(experimental) Create a new IPAddress target.
 
         The availabilityZone parameter determines whether the target receives
         traffic from the load balancer nodes in the specified Availability Zone
@@ -166,7 +159,6 @@ class IpTarget(
         :param port: Override the group's default port.
         :param availability_zone: Availability zone to send traffic from.
 
-        stability
         :stability: experimental
         """
         jsii.create(IpTarget, self, [ip_address, port, availability_zone])
@@ -176,14 +168,13 @@ class IpTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
@@ -193,14 +184,13 @@ class IpTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
@@ -212,16 +202,14 @@ class LambdaTarget(
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.LambdaTarget",
 ):
     """
-    stability
     :stability: experimental
     """
 
     def __init__(self, fn: aws_cdk.aws_lambda.IFunction) -> None:
-        """Create a new Lambda target.
+        """(experimental) Create a new Lambda target.
 
         :param fn: -
 
-        stability
         :stability: experimental
         """
         jsii.create(LambdaTarget, self, [fn])
@@ -231,14 +219,13 @@ class LambdaTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
@@ -248,14 +235,13 @@ class LambdaTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
